Module strings

Module strings 

Definition of Strings

Structs

RosString
String. N represents the maximum number of characters excluding \0. If N is 0, the string is unlimited.
RosStringSeq
Sequence of string. STRLEN represents the maximum number of characters excluding \0. If STRLEN is 0, the string is unlimited. SEQLEN represents the maximum number of elements in a sequence. If SEQLEN is 0, the sequence is unlimited.
RosWString
WString. N represents the maximum number of characters excluding \0. If N is 0, the string is unlimited.
RosWStringSeq
Sequence of WString. STRLEN represents the maximum number of characters excluding \0. If STRLEN is 0, the string is unlimited. SEQLEN represents the maximum number of elements in a sequence. If SEQLEN is 0, the sequence is unlimited.