pub struct RosWStringSeq<const STRLEN: usize, const SEQLEN: usize>(/* private fields */);Expand description
Sequence of WString.
STRLEN represents the maximum number of characters excluding \0.
If STRLEN is 0, the string is unlimited.
SEQLEN represents the maximum number of elements in a sequence.
If SEQLEN is 0, the sequence is unlimited.
Implementations
Sourceimpl<const STRLEN: usize, const SEQLEN: usize> RosWStringSeq<STRLEN, SEQLEN>
impl<const STRLEN: usize, const SEQLEN: usize> RosWStringSeq<STRLEN, SEQLEN>
pub fn new(size: usize) -> Option<Self>
pub fn null() -> Self
pub fn as_slice(&self) -> &[RosWString<STRLEN>]
pub fn as_mut_slice(&mut self) -> &mut [RosWString<STRLEN>]
pub fn iter(&self) -> Iter<'_, RosWString<STRLEN>>
pub fn iter_mut(&mut self) -> IterMut<'_, RosWString<STRLEN>>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool